==> haskell-skein-1.0.9.4-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-skein/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skein
version: 1.0.9.4
id: skein-1.0.9.4-403a459122a5f86f1575bd5c2d5cfd5a
key: skein_Gu4ZCUdyHoJKdYGOgDHOva
license: BSD3
maintainer: Felipe Lessa <felipe.lessa@gmail.com>
homepage: https://github.com/meteficha/skein
synopsis: Skein, a family of cryptographic hash functions.  Includes Skein-MAC as well.
description:
    Skein (<http://www.skein-hash.info/>) is a family of fast
    secure cryptographic hash functions designed by Niels
    Ferguson, Stefan Lucks, Bruce Schneier, Doug Whiting, Mihir
    Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
    .
    This package uses bindings to the optimized C implementation
    of Skein.  We provide a high-level interface (see module
    "Crypto.Skein") to some of the Skein use cases.  We also
    provide a low-level interface (see module
    "Crypto.Skein.Internal") should you need to use Skein in a
    different way.
    .
    Currently we have support for Skein as cryptographic hash
    function as Skein as a message authentication code
    (Skein-MAC).  For examples of how to use this package, see
    "Crypto.Skein" module documentation.
    .
    This package includes Skein v1.3. Versions of this package
    before 1.0.0 implemented Skein v1.1.
category: Cryptography
author: Felipe Lessa <felipe.lessa@gmail.com>, Doug Whiting
exposed: True
exposed-modules:
    Crypto.Skein Crypto.Skein.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/skein-1.0.9.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/skein-1.0.9.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/skein-1.0.9.4
hs-libraries: HSskein-1.0.9.4-Gu4ZCUdyHoJKdYGOgDHOva
includes:
    skein.h
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    crypto-api-0.13.2-095d0cf567bb83558b8b8ae881dd04fd
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
haddock-interfaces: /usr/share/doc/haskell-skein/html/skein.haddock
haddock-html: /usr/share/doc/haskell-skein/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skein-1.0.9.4-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-skein/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skein
version: 1.0.9.4
id: skein-1.0.9.4-f2708f40ed7cebb6812369c52e8487ae
key: skein_Er8QdQfWtp79PgFByyaiMF
license: BSD3
maintainer: Felipe Lessa <felipe.lessa@gmail.com>
homepage: https://github.com/meteficha/skein
synopsis: Skein, a family of cryptographic hash functions.  Includes Skein-MAC as well.
description:
    Skein (<http://www.skein-hash.info/>) is a family of fast
    secure cryptographic hash functions designed by Niels
    Ferguson, Stefan Lucks, Bruce Schneier, Doug Whiting, Mihir
    Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
    .
    This package uses bindings to the optimized C implementation
    of Skein.  We provide a high-level interface (see module
    "Crypto.Skein") to some of the Skein use cases.  We also
    provide a low-level interface (see module
    "Crypto.Skein.Internal") should you need to use Skein in a
    different way.
    .
    Currently we have support for Skein as cryptographic hash
    function as Skein as a message authentication code
    (Skein-MAC).  For examples of how to use this package, see
    "Crypto.Skein" module documentation.
    .
    This package includes Skein v1.3. Versions of this package
    before 1.0.0 implemented Skein v1.1.
category: Cryptography
author: Felipe Lessa <felipe.lessa@gmail.com>, Doug Whiting
exposed: True
exposed-modules:
    Crypto.Skein Crypto.Skein.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/skein-1.0.9.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/skein-1.0.9.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/skein-1.0.9.4
hs-libraries: HSskein-1.0.9.4-Er8QdQfWtp79PgFByyaiMF
includes:
    skein.h
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    crypto-api-0.13.2-6578ff0df46f6893eafa074007e52b3d
    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
haddock-interfaces: /usr/share/doc/haskell-skein/html/skein.haddock
haddock-html: /usr/share/doc/haskell-skein/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
